iXBRL Viewer Continuation Document

1234 2018-01-01 2018-12-31 1234 2017-01-01 2017-12-31

# ix:continuation test document

This is the first part of a continued tag.

Text not included.

This is the second part of a continued tag.

Text not included.

This is the third part of a continued tag.

This is a text tag with a continuation in every other word.

Overlapping facts using ix:continuation

This is the content of footnote 1.

This is the content of footnote 2. It's much longer that footnote 1 and has multiple paragraphs.

It also has bold and italic text, and contains a nested footnote. And a nested fact.

It's also associated with multiple facts.

This is footnote 3 which is split with continuations

This tag is continued in the table

Double tagged table cell | This is a text tag and a continuation